if (requireNamespace("testthat", quietly = TRUE)) {
  library("testthat")
  library("checkmate")
  test_check("bbotk")
}
